// Copyright (C) 2019  Wilko Manger
//
// This file is part of matrix-dart-sdk.
//
// matrix-dart-sdk is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// matrix-dart-sdk is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with matrix-dart-sdk.  If not, see <https://www.gnu.org/licenses/>.

import 'package:matrix_sdk/src/storables.dart';
import 'package:matrix_sdk/src/identifier.dart';
import 'package:matrix_sdk/src/room/room.dart';
import 'package:matrix_sdk/src/store.dart';
import 'package:matrix_sdk/src/user.dart';
import 'package:meta/meta.dart';

class Members extends Storables<UserId, User> {

  final RoomId _roomId;

  Members(this._roomId, {Store store}) : super(store: store);

  @override
  @protected
  Future<User> retrieve(UserId id) => store?.getMember(_roomId, id);

  @override
  @protected
  Stream<User> retrieveAll() => store?.getMembers(_roomId);

  @override
  @protected
  Future<void> saveAll(Iterable<User> users) => store?.addMembers(_roomId, users);

  @override
  @protected
  Stream<User> retrieveUpTo(int count, {@required User from})
  => store?.getMembers(_roomId);
}
